/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/
#include "gtkshell.h"

static void
file_dialog_submit(GtkWidget * dialog)
{
	gchar *name;

	name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
	g_print("%s\n", name);
	g_free(name);
}

/* Taken from the GTK+ Reference Manual */
void
gsh_file_dialog(struct GSH * gsh, GtkFileChooserAction action)
{
	GtkWidget *dialog;

	dialog=gtk_file_chooser_dialog_new("File Chooser", 
		GTK_WINDOW(gsh->widgets.window), action, GTK_STOCK_CANCEL, 
		GTK_RESPONSE_CANCEL, GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);

	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
		file_dialog_submit(dialog);

	exit(0);
}


